pub struct Entry {
pub label: String,
pub shares: Shares,
pub age: Option<i64>,
}Expand description
An enrolled account other than the one in use.
Fields
label: Stringage: Option<i64>Seconds since this was measured, once that is worth knowing.