settle

Function settle 

pub fn settle(
    ctx: &Context,
    tool: Option<ProviderId>,
) -> Result<(Settled, Option<Recovered>)>
What recovery found is returned apart from the Settled, so it can be reported whether or not the command that follows succeeds.

tool is the tool the change that follows is about, where it is about one.