settle

Function settle 

pub fn settle(ctx: &Context) -> Result<(Settled, Option<Recovered>)>
What recovery found is returned apart from the Settled, so it can be reported whether or not the command that follows succeeds.